"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from .address import *
from .addresscompletecreaterequest import *
from .addresscreaterequest import *
from .addressimporter import *
from .addresspaginatedlist import *
from .addressvalidationresults import *
from .addressvalidationresultsmessage import *
from .alcohol import *
from .batch import *
from .batchcreaterequest import *
from .batchshipment import *
from .batchshipmentbase import *
from .batchshipmentpaginatedlist import *
from .billing import *
from .carrieraccount import *
from .carrieraccountbase import *
from .carrieraccountcanadapostcreateparameters import *
from .carrieraccountcanadapostcreaterequest import *
from .carrieraccountchronopostcreaterequest import *
from .carrieraccountcolissimocreaterequest import *
from .carrieraccountcorreoscreaterequest import *
from .carrieraccountdeutschepostcreaterequest import *
from .carrieraccountdhlexpresscreaterequest import *
from .carrieraccountdhlexpresscreaterequestparameters import *
from .carrieraccountdpddecreaterequest import *
from .carrieraccountdpdukcreaterequest import *
from .carrieraccounthermesukcreaterequest import *
from .carrieraccountpaginatedlist import *
from .carrieraccountposteitalianecreaterequest import *
from .carrieraccountregistrationstatus import *
from .carrieraccountservicelevel import *
from .carrieraccountupscreaterequest import *
from .carrieraccountupscreaterequestparameters import *
from .carrieraccountuspscreaterequest import *
from .carrierparceltemplate import *
from .carriers import *
from .cod import *
from .connectexistingownupsaccountrequest import *
from .customerreference import *
from .customsdeclaration import *
from .customsdeclarationcreaterequest import *
from .customsdeclarationpaginatedlist import *
from .customsexporteridentification import *
from .customsinvoicedcharges import *
from .customsitem import *
from .customsitembase import *
from .customsitempaginatedlist import *
from .customstaxidentification import *
from .dangerousgoodsbiologicalmaterial import *
from .dangerousgoodslithiumbatteries import *
from .dangerousgoodsobject import *
from .defaultparceltemplate import *
from .defaultparceltemplateupdaterequest import *
from .departmentnumber import *
from .distanceunit import *
from .dryice import *
from .errormessage import *
from .instanttransactionrequestbody import *
from .insurance import *
from .invoicenumber import *
from .labelfiletype import *
from .lineitem import *
from .lineitembase import *
from .liverate import *
from .liveratecreaterequest import *
from .liveratepaginatedlist import *
from .location import *
from .manifest import *
from .manifestcreaterequest import *
from .manifestpaginatedlist import *
from .objectstate import *
from .order import *
from .ordercreaterequest import *
from .orderpaginatedlist import *
from .parcel import *
from .parcelcreaterequest import *
from .parcelextra import *
from .parcelinsurance import *
from .parcelpaginatedlist import *
from .parcelrequest import *
from .parceltemplateenumset import *
from .pickup import *
from .pickupbase import *
from .ponumber import *
from .rate import *
from .ratemessage import *
from .ratepaginatedlist import *
from .refund import *
from .refundpaginatedlist import *
from .refundrequestbody import *
from .rmanumber import *
from .security import *
from .servicegroup import *
from .servicegroupaccountandservicelevel import *
from .servicegroupcreaterequest import *
from .servicegrouptype import *
from .servicegroupupdaterequest import *
from .servicelevel import *
from .servicelevelenumset import *
from .shipment import *
from .shipmentcreaterequest import *
from .shipmentextra import *
from .shipmentpaginatedlist import *
from .shippoaccount import *
from .shippoaccountpaginatedlist import *
from .shippoaccountupdaterequest import *
from .track import *
from .trackingstatus import *
from .trackingstatusenum import *
from .trackingstatuslocationbase import *
from .trackingstatussubstatus import *
from .tracksrequest import *
from .transaction import *
from .transactioncreaterequest import *
from .transactionpaginatedlist import *
from .transactionstatusenum import *
from .upsconnectexistingownaccountparameters import *
from .userparceltemplate import *
from .userparceltemplateupdaterequest import *
from .userparceltemplatewithcarriertemplatecreaterequest import *
from .userparceltemplatewithoutcarriertemplatecreaterequest import *
from .weightunit import *

__all__ = ["Address","AddressCompleteCreateRequest","AddressCreateRequest","AddressImporter","AddressPaginatedList","AddressValidationResults","AddressValidationResultsMessage","Alcohol","AncillaryEndorsement","Attributes","B13aFilingOption","Batch","BatchCreateRequest","BatchShipment","BatchShipmentBase","BatchShipmentPaginatedList","BatchStatus","Billing","BuildingLocationType","BuildingType","CarrierAccount","CarrierAccountBase","CarrierAccountCanadaPostCreateParameters","CarrierAccountCanadaPostCreateRequest","CarrierAccountChronopostCreateRequest","CarrierAccountColissimoCreateRequest","CarrierAccountColissimoCreateRequestParameters","CarrierAccountCorreosCreateRequest","CarrierAccountCorreosCreateRequestParameters","CarrierAccountDHLExpressCreateRequest","CarrierAccountDHLExpressCreateRequestParameters","CarrierAccountDPDUKCreateRequest","CarrierAccountDPDUKCreateRequestParameters","CarrierAccountDeutschePostCreateRequest","CarrierAccountDeutschePostCreateRequestParameters","CarrierAccountDpdDeCreateRequest","CarrierAccountDpdDeCreateRequestParameters","CarrierAccountHermesUKCreateRequest","CarrierAccountHermesUKCreateRequestParameters","CarrierAccountPaginatedList","CarrierAccountPosteItalianeCreateRequest","CarrierAccountPosteItalianeCreateRequestParameters","CarrierAccountRegistrationStatus","CarrierAccountServiceLevel","CarrierAccountUPSCreateRequest","CarrierAccountUPSCreateRequestParameters","CarrierAccountUSPSCreateRequest","CarrierAccountUSPSCreateRequestParameters","CarrierParcelTemplate","Carriers","Cod","Code","ConnectExistingOwnUPSAccountRequest","ContentsType","CustomerReference","CustomsDeclaration","CustomsDeclarationAddressImporter","CustomsDeclarationCreateRequest","CustomsDeclarationCreateRequestB13aFilingOption","CustomsDeclarationCreateRequestContentsType","CustomsDeclarationCreateRequestEelPfc","CustomsDeclarationCreateRequestIncoterm","CustomsDeclarationCreateRequestNonDeliveryOption","CustomsDeclarationPaginatedList","CustomsExporterIdentification","CustomsInvoicedCharges","CustomsItem","CustomsItemBase","CustomsItemPaginatedList","CustomsTaxIdentification","CustomsTaxIdentificationType","DangerousGoodsBiologicalMaterial","DangerousGoodsCode","DangerousGoodsLithiumBatteries","DangerousGoodsObject","DefaultParcelTemplate","DefaultParcelTemplateUpdateRequest","DepartmentNumber","DistanceUnit","DryIce","EelPfc","ErrorMessage","Incoterm","InstantTransactionRequestBody","InstantTransactionRequestBodyLabelFileType","Insurance","InvoiceNumber","LabelFileType","LasershipAttrs","LineItem","LineItemBase","LiveRate","LiveRateCreateRequest","LiveRatePaginatedList","Location","Manifest","ManifestCreateRequest","ManifestPaginatedList","ManifestStatus","Messages","NonDeliveryOption","ObjectResults","ObjectState","Order","OrderCreateRequest","OrderCreateRequestOrderStatus","OrderPaginatedList","OrderStatus","Parameters","Parcel","ParcelCreateRequest","ParcelExtra","ParcelInsurance","ParcelInsuranceProvider","ParcelObjectState","ParcelPaginatedList","ParcelRequest","ParcelTemplateAramexAustralia","ParcelTemplateCouriersPlease","ParcelTemplateDHLeCommerce","ParcelTemplateDPDUK","ParcelTemplateFedEx","ParcelTemplateUPS","ParcelTemplateUSPS","PaymentMethod","Pickup","PickupBase","PickupStatus","PoNumber","PreferredDeliveryTimeframe","Provider","Rate","RateMessage","RatePaginatedList","RecipientType","Refund","RefundPaginatedList","RefundRequestBody","RefundStatus","ReturnServiceType","RmaNumber","Security","ServiceGroup","ServiceGroupAccountAndServiceLevel","ServiceGroupCreateRequest","ServiceGroupType","ServiceGroupUpdateRequest","ServiceLevel","ServiceLevelAPCPostal","ServiceLevelAPG","ServiceLevelAirterra","ServiceLevelAramexAustralia","ServiceLevelAsendia","ServiceLevelAustraliaPost","ServiceLevelAxleHire","ServiceLevelBetterTrucks","ServiceLevelCDL","ServiceLevelCanadaPost","ServiceLevelChronopost","ServiceLevelColissimo","ServiceLevelCorreosEspana","ServiceLevelCouriersPlease","ServiceLevelDHLExpress","ServiceLevelDHLGermany","ServiceLevelDHLeCommerce","ServiceLevelDPDDE","ServiceLevelDPDUK","ServiceLevelDeutschePost","ServiceLevelEvriUK","ServiceLevelFedEx","ServiceLevelGLSUS","ServiceLevelGlobegistics","ServiceLevelLSO","ServiceLevelLasership","ServiceLevelMaergo","ServiceLevelMondialRelay","ServiceLevelOnTrac","ServiceLevelParcelforce","ServiceLevelPostItaliane","ServiceLevelPurolator","ServiceLevelRoyalMail","ServiceLevelSendle","ServiceLevelSwyft","ServiceLevelUDS","ServiceLevelUPS","ServiceLevelUSPS","ServiceLevelVeho","ServiceLevelePostGlobal","Shipment","ShipmentCreateRequest","ShipmentExtra","ShipmentPaginatedList","ShipmentStatus","ShippoAccount","ShippoAccountPaginatedList","ShippoAccountUpdateRequest","ShopApp","SignatureConfirmation","Source","Status","Track","TrackingStatus","TrackingStatusEnum","TrackingStatusLocationBase","TrackingStatusSubstatus","TracksRequest","Transaction","TransactionCreateRequest","TransactionMessages","TransactionPaginatedList","TransactionStatusEnum","Type","UPSConnectExistingOwnAccountParameters","UserParcelTemplate","UserParcelTemplateUpdateRequest","UserParcelTemplateWithCarrierTemplateCreateRequest","UserParcelTemplateWithoutCarrierTemplateCreateRequest","WeightUnit"]



"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from .upsconnectexistingownaccountparameters import UPSConnectExistingOwnAccountParameters
from dataclasses_json import Undefined, dataclass_json
from shippo import utils
from typing import Optional


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class ConnectExistingOwnUPSAccountRequest:
    account_id: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('account_id') }})
    r"""This field is required as input to the API, but is not used for UPS. Use the empty string."""
    active: bool = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('active') }})
    parameters: UPSConnectExistingOwnAccountParameters = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('parameters') }})
    r"""An array of additional parameters for the account, such as e.g. password or token.
    Please check the <a href=\"https://docs.goshippo.com/docs/carriers/carrieraccounts/\">carrier accounts tutorial</a> page for the parameters per carrier.<br> 
    To protect account information, this field will be masked in any API response.
    """
    carrier: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('carrier'), 'exclude': lambda f: f is None }})
    metadata: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('metadata'), 'exclude': lambda f: f is None }})
    test: Optional[bool] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('test'), 'exclude': lambda f: f is None }})
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from dataclasses_json import Undefined, dataclass_json
from shippo import utils
from typing import Optional


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class LiveRate:
    amount: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('amount'), 'exclude': lambda f: f is None }})
    r"""The value of the price for the service group, in units of currency of the sender address"""
    amount_local: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('amount_local'), 'exclude': lambda f: f is None }})
    r"""The value of the price for the service group, in the currency of the destination address"""
    currency: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('currency'), 'exclude': lambda f: f is None }})
    r"""The ISO 4217 currency code for the price"""
    currency_local: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('currency_local'), 'exclude': lambda f: f is None }})
    r"""The ISO 4217 currency code for the currency describing amount_local"""
    estimated_days: Optional[int] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('estimated_days'), 'exclude': lambda f: f is None }})
    r"""The estimated days in transit of the rate that powers the shipping option, if available."""
    title: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('title'), 'exclude': lambda f: f is None }})
    r"""The name of the service group being returned"""
    




"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from .addshipmentstobatch import *
from .createaddress import *
from .createbatch import *
from .createcarrieraccount import *
from .createcustomsdeclaration import *
from .createcustomsitem import *
from .createliverate import *
from .createmanifest import *
from .createorder import *
from .createparcel import *
from .createpickup import *
from .createrefund import *
from .createservicegroup import *
from .createshipment import *
from .createshippoaccount import *
from .createtrack import *
from .createtransaction import *
from .createuserparceltemplate import *
from .deletedefaultparceltemplate import *
from .deleteservicegroup import *
from .deleteuserparceltemplate import *
from .getaddress import *
from .getbatch import *
from .getcarrieraccount import *
from .getcarrierparceltemplate import *
from .getcarrierregistrationstatus import *
from .getcustomsdeclaration import *
from .getcustomsitem import *
from .getdefaultparceltemplate import *
from .getmanifest import *
from .getorder import *
from .getparcel import *
from .getrate import *
from .getrefund import *
from .getshipment import *
from .getshippoaccount import *
from .gettrack import *
from .gettransaction import *
from .getuserparceltemplate import *
from .listaddresses import *
from .listcarrieraccounts import *
from .listcarrierparceltemplates import *
from .listcustomsdeclarations import *
from .listcustomsitems import *
from .listmanifests import *
from .listorders import *
from .listparcels import *
from .listrefunds import *
from .listservicegroups import *
from .listshipmentrates import *
from .listshipmentratesbycurrencycode import *
from .listshipments import *
from .listshippoaccounts import *
from .listtransactions import *
from .listuserparceltemplates import *
from .purchasebatch import *
from .registercarrieraccount import *
from .removeshipmentsfrombatch import *
from .updatecarrieraccount import *
from .updatedefaultparceltemplate import *
from .updateservicegroup import *
from .updateshippoaccount import *
from .updateuserparceltemplate import *
from .validateaddress import *

__all__ = ["AddShipmentsToBatchRequest","Carrier","CreateAddressRequest","CreateBatchRequest","CreateCarrierAccountRequest","CreateCustomsDeclarationRequest","CreateCustomsItemRequest","CreateLiveRateRequest","CreateManifestRequest","CreateOrderRequest","CreateParcelRequest","CreatePickupRequest","CreateRefundRequest","CreateServiceGroupRequest","CreateShipmentRequest","CreateShippoAccountRequest","CreateTrackRequest","CreateTransactionRequest","CreateUserParcelTemplateRequest","DeleteDefaultParcelTemplateRequest","DeleteDefaultParcelTemplateResponse","DeleteServiceGroupRequest","DeleteServiceGroupResponse","DeleteUserParcelTemplateRequest","DeleteUserParcelTemplateResponse","GetAddressRequest","GetBatchRequest","GetCarrierAccountRequest","GetCarrierParcelTemplateRequest","GetCarrierRegistrationStatusRequest","GetCustomsDeclarationRequest","GetCustomsItemRequest","GetDefaultParcelTemplateRequest","GetManifestRequest","GetOrderRequest","GetParcelRequest","GetRateRequest","GetRefundRequest","GetShipmentRequest","GetShippoAccountRequest","GetTrackRequest","GetTransactionRequest","GetUserParcelTemplateRequest","Include","ListAddressesRequest","ListCarrierAccountsRequest","ListCarrierParcelTemplatesRequest","ListCustomsDeclarationsRequest","ListCustomsItemsRequest","ListManifestsRequest","ListOrdersRequest","ListParcelsRequest","ListRefundsRequest","ListServiceGroupsRequest","ListShipmentRatesByCurrencyCodeRequest","ListShipmentRatesRequest","ListShipmentsRequest","ListShippoAccountsRequest","ListTransactionsRequest","ListUserParcelTemplatesRequest","PurchaseBatchRequest","RegisterCarrierAccountRequest","RemoveShipmentsFromBatchRequest","UpdateCarrierAccountRequest","UpdateDefaultParcelTemplateRequest","UpdateServiceGroupRequest","UpdateShippoAccountRequest","UpdateUserParcelTemplateRequest","ValidateAddressRequest"]
